% Script for investigating relationships between speed numbers and 
% curve coefficients in the four different proposed eta_i(q) curves

clear all
close all
clc

%--------------------------------------------------------------------------
% High head turbine
%--------------------------------------------------------------------------
data=table2array(readtable('Hillchart_r3_medBEP.xlsx','Sheet','Hy',...
                           'Range','B2:F257'));
etaM=data(:,1); Q11=data(:,2); N11=data(:,3); T11=data(:,4); alfa=data(:,5);
positive=find(etaM>=0);
etaM=etaM(positive); Q11=Q11(positive); N11=N11(positive); T11=T11(positive); alfa=alfa(positive);
etaM_R=max(etaM);
pos1=find(etaM==etaM_R);
Q11_R=Q11(pos1); N11_R=N11(pos1); T11_R=T11(pos1); alfa_R=alfa(pos1);
eta=etaM./etaM_R; q=Q11./Q11_R; n=N11./N11_R; t=T11./T11_R; y=sind(alfa)./sind(alfa_R);
model_inputs=table2array(readtable('Hillchart_r3_medBEP.xlsx','Sheet',...
                                   'Turbin_design','Range','U31:U65'));
alfa_1R=model_inputs(27,1); sigma=model_inputs(31,1); psi=model_inputs(32,1); xi=model_inputs(34,1);
speednumber=model_inputs(1,1);

n_query=linspace(0.8,1.3,11);
dq=0.01;
qhalf1=linspace(min(q),1,ceil((1-min(q))/dq));
qhalf2=linspace(1,max(q),ceil((max(q)-1)/dq));
q_query=[qhalf1 qhalf2(2:end)];
[N,Q]=meshgrid(n_query,q_query);
F = scatteredInterpolant(n,q,eta,'natural');
ETA=F(N,Q);

n1=1.0;
pos2=find(n_query==n1);
q1=Q(:,pos2); eta_meas=ETA(:,pos2);
eta_model=xi*(cos(asin(q1.*sind(alfa_1R))) + q1.*tand(alfa_1R)*sind(alfa_1R)) - psi;
eta_i=eta_meas./eta_model;

for j=1:length(q1)
   if q1(j)>1.57
      break
   end
end
q1=q1(1:j-1); eta_meas=eta_meas(1:j-1); eta_model=eta_model(1:j-1); eta_i=eta_i(1:j-1); 
eta_i_before=eta_i;
eta_i=smooth(eta_i);

w=ones(size(eta_i));
pos3=find(q_query==1);
w(pos3)=10;

poly=fit([q1;2],[eta_i;0],'poly9','Weight',[w;1]);

fou=fit([q1;2],[eta_i;0],'fourier6','Weight',[w;1]);

pos4=find(q1<=1); pos5=find(q1>=1);
q1_1=q1(pos4); q1_2=q1(pos5);
eta_i_1=eta_i(pos4); eta_i_2=eta_i(pos5);

w1=ones(size(eta_i_1)); w1(end)=1000;
w2=ones(size(eta_i_2)); w2(1)=1000;

expo1=fit(q1_1,eta_i_1,'exp2','Weight', w1);
expo2=fit(q1_2,eta_i_2,'exp2','Weight', w2);

pow1=fit(q1_1,eta_i_1,'power2','Weight', w1);
pow2=fit(q1_2,eta_i_2,'power2','Weight', w2);

speednumber_highH=speednumber;

p1_high = poly.p1;
p2_high = poly.p2;
p3_high = poly.p3;
p4_high = poly.p4;
p5_high = poly.p5;
p6_high = poly.p6;
p7_high = poly.p7;
p8_high = poly.p8;
p9_high = poly.p9;
p10_high = poly.p10;

a0_high = fou.a0;
a1_high = fou.a1;
b1_high = fou.b1;
a2_high = fou.a2;
b2_high = fou.b2;
a3_high = fou.a3;
b3_high = fou.b3;
a4_high = fou.a4;
b4_high = fou.b4;
a5_high = fou.a5;
b5_high = fou.b5;
a6_high = fou.a6;
b6_high = fou.b6;
w_high = fou.w;

exp1_a_high=expo1.a;
exp1_b_high=expo1.b;
exp1_c_high=expo1.c;
exp1_d_high=expo1.d;
exp2_a_high=expo2.a;
exp2_b_high=expo2.b;
exp2_c_high=expo2.c;
exp2_d_high=expo2.d;

pow1_a_high=pow1.a;
pow1_b_high=pow1.b;
pow1_c_high=pow1.c;
pow2_a_high=pow2.a;
pow2_b_high=pow2.b;
pow2_c_high=pow2.c;


figure(1)
plot(q1,eta_i,'r-','Linewidth',1)
hold on


%--------------------------------------------------------------------------
% Medium head turbine
%--------------------------------------------------------------------------
data=table2array(readtable('Hillchart_r3_medBEP.xlsx','Sheet','Mellom2',...
                           'Range','L2:P305'));
etaM=data(:,1); Q11=data(:,2); N11=data(:,3); T11=data(:,4); alfa=data(:,5);
positive=find(etaM>=0);
etaM=etaM(positive); Q11=Q11(positive); N11=N11(positive); T11=T11(positive); alfa=alfa(positive);
etaM_R=max(etaM);
pos1=find(etaM==etaM_R);
Q11_R=Q11(pos1); N11_R=N11(pos1); T11_R=T11(pos1); alfa_R=alfa(pos1);
eta=etaM./etaM_R; q=Q11./Q11_R; n=N11./N11_R; t=T11./T11_R; y=sind(alfa)./sind(alfa_R);
model_inputs=table2array(readtable('Hillchart_r3_medBEP.xlsx','Sheet',...
                                   'Turbin_design','Range','T31:T65'));
alfa_1R=model_inputs(27,1); sigma=model_inputs(31,1); psi=model_inputs(32,1); xi=model_inputs(34,1);
speednumber=model_inputs(1,1);

n_query=linspace(0.9,1.7,17);
dq=0.01;
qhalf1=linspace(min(q),1,ceil((1-min(q))/dq));
qhalf2=linspace(1,max(q),ceil((max(q)-1)/dq));
q_query=[qhalf1 qhalf2(2:end)];
[N,Q]=meshgrid(n_query,q_query);                                       
F = scatteredInterpolant(n,q,eta,'natural');
ETA=F(N,Q);

n1=1.0;
pos2=find(n_query==n1);
q1=Q(:,pos2); eta_meas=ETA(:,pos2);
eta_model=xi*(cos(asin(q1.*sind(alfa_1R))) + q1.*tand(alfa_1R)*sind(alfa_1R)) - psi;
eta_i=eta_meas./eta_model;

for j=1:length(q1)
   if q1(j)>1.48
      break
   end
end
q1=q1(1:j-1); eta_meas=eta_meas(1:j-1); eta_model=eta_model(1:j-1); eta_i=eta_i(1:j-1); 
eta_i_before=eta_i;
eta_i=smooth(eta_i,12);

w=ones(size(eta_i));
pos3=find(q_query==1);
w(pos3)=10;

poly=fit([q1;2],[eta_i;0],'poly9','Weight',[w;1]);

fou=fit(q1,eta_i,'fourier5','Weight',w);

pos4=find(q1<=1); pos5=find(q1>=1);
q1_1=q1(pos4); q1_2=q1(pos5);
eta_i_1=eta_i(pos4); eta_i_2=eta_i(pos5);

w1=ones(size(eta_i_1)); w1(end)=1000;
w2=ones(size(eta_i_2)); w2(1)=1000;

expo1=fit(q1_1,eta_i_1,'exp2','Weight', w1);
expo2=fit(q1_2,eta_i_2,'exp2','Weight', w2);

pow1=fit(q1_1,eta_i_1,'power2','Weight', w1);
pow2=fit(q1_2,eta_i_2,'power2','Weight', w2);

speednumber_medH_v2=speednumber;

p1_m2 = poly.p1;
p2_m2 = poly.p2;
p3_m2 = poly.p3;
p4_m2 = poly.p4;
p5_m2 = poly.p5;
p6_m2 = poly.p6;
p7_m2 = poly.p7;
p8_m2 = poly.p8;
p9_m2 = poly.p9;
p10_m2 = poly.p10;

a0_m2 = fou.a0;
a1_m2 = fou.a1;
b1_m2 = fou.b1;
a2_m2 = fou.a2;
b2_m2 = fou.b2;
a3_m2 = fou.a3;
b3_m2 = fou.b3;
a4_m2 = fou.a4;
b4_m2 = fou.b4;
a5_m2 = fou.a5;
b5_m2 = fou.b5;
w_m2 = fou.w;

exp1_a_m2=expo1.a;
exp1_b_m2=expo1.b;
exp1_c_m2=expo1.c;
exp1_d_m2=expo1.d;
exp2_a_m2=expo2.a;
exp2_b_m2=expo2.b;
exp2_c_m2=expo2.c;
exp2_d_m2=expo2.d;

pow1_a_m2=pow1.a;
pow1_b_m2=pow1.b;
pow1_c_m2=pow1.c;
pow2_a_m2=pow2.a;
pow2_b_m2=pow2.b;
pow2_c_m2=pow2.c;


figure(1)
plot(q1,eta_i,'b-','Linewidth',1)
hold on


%--------------------------------------------------------------------------
% Low head turbine
%--------------------------------------------------------------------------
data=table2array(readtable('Hillchart_r3_medBEP.xlsx','Sheet','Lavtrykk',...
                           'Range','B2:F119'));
etaM=data(:,1); Q11=data(:,2); N11=data(:,3); T11=data(:,4); alfa=data(:,5);
positive=find(etaM>=0);
etaM=etaM(positive); Q11=Q11(positive); N11=N11(positive); T11=T11(positive); alfa=alfa(positive);
etaM_R=max(etaM);
pos1=find(etaM==etaM_R);
Q11_R=Q11(pos1); N11_R=N11(pos1); T11_R=T11(pos1); alfa_R=alfa(pos1);
eta=etaM./etaM_R; q=Q11./Q11_R; n=N11./N11_R; t=T11./T11_R; y=sind(alfa)./sind(alfa_R);
model_inputs=table2array(readtable('Hillchart_r3_medBEP.xlsx','Sheet',...
                                   'Turbin_design','Range','R31:R65'));
alfa_1R=model_inputs(27,1); sigma=model_inputs(31,1); psi=model_inputs(32,1); xi=model_inputs(34,1);
speednumber=model_inputs(1,1);

n_query=linspace(0.95,1.45,11);
dq=0.01;
qhalf1=linspace(min(q),1,ceil((1-min(q))/dq));
qhalf2=linspace(1,max(q),ceil((max(q)-1)/dq));
q_query=[qhalf1 qhalf2(2:end)];
[N,Q]=meshgrid(n_query,q_query);                                        
F = scatteredInterpolant(n,q,eta,'natural');
ETA=F(N,Q);

n1=1.0;
pos2=find(n_query==n1);
q1=Q(:,pos2); eta_meas=ETA(:,pos2);
eta_model=xi*(cos(asin(q1.*sind(alfa_1R))) + q1.*tand(alfa_1R)*sind(alfa_1R)) - psi;
eta_i=eta_meas./eta_model;

for j=1:length(q1)
   if q1(j)>1.20
      break
   end
end
q1=q1(1:j-1); eta_meas=eta_meas(1:j-1); eta_model=eta_model(1:j-1); eta_i=eta_i(1:j-1); 
eta_i_before=eta_i;
eta_i=smooth(eta_i,8);

w=ones(size(eta_i));
pos3=find(q_query==1);
w(pos3)=10;

poly=fit(q1,eta_i,'poly4','Weight',w);

fou=fit(q1,eta_i,'fourier5','Weight',w);

pos4=find(q1<=1); pos5=find(q1>=1);
q1_1=q1(pos4); q1_2=q1(pos5);
eta_i_1=eta_i(pos4); eta_i_2=eta_i(pos5);

w1=ones(size(eta_i_1)); w1(end)=1000;
w2=ones(size(eta_i_2)); w2(1)=1000;

expo1=fit(q1_1,eta_i_1,'exp2','Weight', w1);
expo2=fit(q1_2,eta_i_2,'exp2','Weight', w2);

pow1=fit(q1_1,eta_i_1,'power2','Weight', w1);
pow2=fit(q1_2,eta_i_2,'power2','Weight', w2);

speednumber_lowH=speednumber;

p1_low = poly.p1;
p2_low = poly.p2;
p3_low = poly.p3;
p4_low = poly.p4;
p5_low = poly.p5;

a0_low = fou.a0;
a1_low = fou.a1;
b1_low = fou.b1;
a2_low = fou.a2;
b2_low = fou.b2;
a3_low = fou.a3;
b3_low = fou.b3;
a4_low = fou.a4;
b4_low = fou.b4;
a5_low = fou.a5;
b5_low = fou.b5;
w_low = fou.w;

exp1_a_low=expo1.a;
exp1_b_low=expo1.b;
exp1_c_low=expo1.c;
exp1_d_low=expo1.d;
exp2_a_low=expo2.a;
exp2_b_low=expo2.b;
exp2_c_low=expo2.c;
exp2_d_low=expo2.d;

pow1_a_low=pow1.a;
pow1_b_low=pow1.b;
pow1_c_low=pow1.c;
pow2_a_low=pow2.a;
pow2_b_low=pow2.b;
pow2_c_low=pow2.c;


%--------------------------------------------------------------------------
% Plot curve fitting basises for shape comparison
%--------------------------------------------------------------------------

%legends
txt_highH=['High head, $\Omega$ = ',num2str(round(speednumber_highH,2))];
txt_medH_v2=['Medium head, $\Omega$ = ',num2str(round(speednumber_medH_v2,2))];
txt_lowH=['Low head, $\Omega$ = ',num2str(round(speednumber_lowH,2))];

figure(1)
plot(q1,eta_i,'g-','Linewidth',1)
legend(txt_highH,txt_medH_v2,txt_lowH)
set(legend,'Interpreter','latex','FontSize',10,'Location','south')
title('Experimental data divided by model efficiency','Interpreter','latex','FontSize',16)
xlabel('q [-]','Interpreter','latex','FontSize',16)
ylabel('$\tilde{\eta}$ [-]','Interpreter','latex','FontSize',16)
axis([0 2 0 1.1])
hold off


%--------------------------------------------------------------------------
% INVESTIGATE RELATIONS BETWEEN CURVE COEFFICIENTS AND SPEED NUMBERS
%--------------------------------------------------------------------------
% x-axis
s=[speednumber_highH, speednumber_medH_v2, speednumber_lowH];

%--------------------------------------------------------------------------
% 1. Polynomial coefficients relationships
%--------------------------------------------------------------------------
% y-axis
p1=[p1_high, p1_m2, p1_low];
p2=[p2_high, p2_m2, p2_low];
p3=[p3_high, p3_m2, p3_low];
p4=[p4_high, p4_m2, p4_low];
p5=[p5_high, p5_m2, p5_low];
% p6=[p6_high, p6_m2, p6_low];
% p7=[p7_high, p7_m2, p7_low];
% p8=[p8_high, p8_m2, p8_low];
% p9=[p9_high, p9_m2, p9_low];

% s,p6,'g*-',s,p7,'bo-',s,p8,'ro-',s,p9,'co-',
% ,'p6','p7','p8','p9'

figure(2)
plot(s,p1,'b*-',s,p2,'r*-',s,p3,'c*-',s,p4,'m*-',s,p5,'k*-','Linewidth',1);
legend('p1','p2','p3','p4','p5')
set(legend,'Interpreter','latex','FontSize',10)
title('Polynomial coefficients','Interpreter','latex','FontSize',16)
xlabel('Speed number, $\Omega$','Interpreter','latex','FontSize',16)
ylabel('Coefficients','Interpreter','latex','FontSize',16)


%--------------------------------------------------------------------------
% 2. Fourier coefficients relationships
%--------------------------------------------------------------------------
% y-axis
a0=[a0_high, a0_m2, a0_low];
a1=[a1_high, a1_m2, a1_low];
b1=[b1_high, b1_m2, b1_low];
a2=[a2_high, a2_m2, a2_low];
b2=[b2_high, b2_m2, b2_low];
a3=[a3_high, a3_m2, a3_low];
b3=[b3_high, b3_m2, b3_low];
a4=[a4_high, a4_m2, a4_low];
b4=[b4_high, b4_m2, b4_low];
a5=[a5_high, a5_m2, a5_low];
b5=[b5_high, b5_m2, b5_low];
freq=[w_high, w_m2, w_low];

figure(3)
plot(s,a0,'b*-',s,a1,'r*-',s,b1,'c*-',s,a2,'m*-',s,b2,'k*-',s,a3,'g*-',s,b3,'y*-',s,a4,'bo-',s,b4,'ro-',s,a5,'co-',s,b5,'mo-','Linewidth',1);
legend('a0','a1','b1','a2','b2','a3','b3','a4','b4','a5','b5')
set(legend,'Interpreter','latex','FontSize',10)
title('Fourier series coefficients','Interpreter','latex','FontSize',16)
xlabel('Speed number, $\Omega$','Interpreter','latex','FontSize',16)
ylabel('Coefficients','Interpreter','latex','FontSize',16)

figure(4)
plot(s,freq,'co-','Linewidth',1)
legend('$\omega$')
set(legend,'Interpreter','latex','FontSize',10)
title('Fourier series frequencies','Interpreter','latex','FontSize',16)
xlabel('Speed number, $\Omega$','Interpreter','latex','FontSize',16)
ylabel('Frequency, $\omega$','Interpreter','latex','FontSize',16)


%--------------------------------------------------------------------------
% 3. Exponential coefficients relationships
%--------------------------------------------------------------------------
% y-axis
exp1_a=[exp1_a_high, exp1_a_m2, exp1_a_low];
exp1_b=[exp1_b_high, exp1_b_m2, exp1_b_low];
exp1_c=[exp1_c_high, exp1_c_m2, exp1_c_low];
exp1_d=[exp1_d_high, exp1_d_m2, exp1_d_low];
exp2_a=[exp2_a_high, exp2_a_m2, exp2_a_low];
exp2_b=[exp2_b_high, exp2_b_m2, exp2_b_low];
exp2_c=[exp2_c_high, exp2_c_m2, exp2_c_low];
exp2_d=[exp2_d_high, exp2_d_m2, exp2_d_low];

figure(5)
plot(s,exp1_a,'b*-',s,exp1_b,'r*-',s,exp1_c,'c*-',s,exp1_d,'m*-',s,exp2_a,'k*-',s,exp2_b,'g*-',s,exp2_c,'bo-',s,exp2_d,'ro-','Linewidth',1);
legend('a, $q<=1$','b, $q<=1$','c, $q<=1$','d, $q<=1$','a, $q>=1$','b, $q>=1$','c, $q>=1$','d, $q>=1$')
set(legend,'Interpreter','latex','FontSize',10)
title('Exponential function coefficients','Interpreter','latex','FontSize',16)
xlabel('Speed number, $\Omega$','Interpreter','latex','FontSize',16)
ylabel('Coefficients','Interpreter','latex','FontSize',16)


%--------------------------------------------------------------------------
% 4. Power coefficients relationships
%--------------------------------------------------------------------------
% y-axis
pow1_a=[pow1_a_high, pow1_a_m2, pow1_a_low];
pow1_b=[pow1_b_high, pow1_b_m2, pow1_b_low];
pow1_c=[pow1_c_high, pow1_c_m2, pow1_c_low];
pow2_a=[pow2_a_high, pow2_a_m2, pow2_a_low];
pow2_b=[pow2_b_high, pow2_b_m2, pow2_b_low];
pow2_c=[pow2_c_high, pow2_c_m2, pow2_c_low];

figure(6)
plot(s,pow1_a,'b*-',s,pow1_b,'r*-',s,pow1_c,'c*-',s,pow2_a,'m*-',s,pow2_b,'k*-',s,pow2_c,'g*-','Linewidth',1);
legend('a, $q<=1$','b, $q<=1$','c, $q<=1$','a, $q>=1$','b, $q>=1$','c, $q>=1$')
set(legend,'Interpreter','latex','FontSize',10)
title('Power function coefficients','Interpreter','latex','FontSize',16)
xlabel('Speed number, $\Omega$','Interpreter','latex','FontSize',16)
ylabel('Coefficients','Interpreter','latex','FontSize',16)



%--------------------------------------------------------------------------
% LINEAR INTERPOLATION BETWEEN TWO CURVES BASED ON SPEED NUMBER
%--------------------------------------------------------------------------

ds=0.1;
s_query=linspace(speednumber_highH,speednumber_lowH,7);
x=(s_query-speednumber_highH)./(speednumber_lowH-speednumber_highH);

%--------------------------------------------------------------------------
% 1. POLYNOMIAL FUNCTION
%--------------------------------------------------------------------------

q=linspace(0,2,201);

%High head:
f_high = p1_high*q.^9 + p2_high*q.^8 + p3_high*q.^7 + p4_high*q.^6 + p5_high*q.^5 + p6_high*q.^4 + ...
         p7_high*q.^3 + p8_high*q.^2 + p9_high*q + p10_high;                %poly9
%Low head:
f_low = p1_low*q.^4 + p2_low*q.^3 + p3_low*q.^2 + p4_low*q + p5_low;        %poly4

figure(7)
xlabel('q [-]','Interpreter','latex','FontSize',16)
ylabel('$\eta_i$ [-]','Interpreter','latex','FontSize',16)
title('Polynomial $\eta_i ( q )$ curves (n=9)','Interpreter','latex','FontSize',16)
hold on

for i=1:length(x)
    y = (1-x(i))*f_high + x(i)*f_low;
    txt=['$\Omega = $',num2str(round(s_query(i),2))];
    plot(q,y,'-','LineWidth',1,'DisplayName',txt);
    set(legend,'Interpreter','latex','FontSize',10,'Location','south')
end

axis([0 2 0 1.05])
hold off
legend show


%--------------------------------------------------------------------------
% 2. FOURIER SERIES FUNCTION
%--------------------------------------------------------------------------

q=linspace(0,1.5,151);

%High head:
f_high = a0_high + a1_high*cos(1*w_high.*q) + b1_high*sin(1*w_high.*q) + a2_high*cos(2*w_high.*q) + b2_high*sin(2*w_high.*q) + ...
    a3_high*cos(3*w_high.*q) + b3_high*sin(3*w_high.*q) + a4_high*cos(4*w_high.*q) + b4_high*sin(4*w_high.*q) + ...
    a5_high*cos(5*w_high.*q) + b5_high*sin(5*w_high.*q) + a6_high*cos(6*w_high.*q) + b6_high*sin(6*w_high.*q);      %fourier6
%Low head:
f_low = a0_low + a1_low*cos(1*w_low.*q) + b1_low*sin(1*w_low.*q) + a2_low*cos(2*w_low.*q) + b2_low*sin(2*w_low.*q) + ...
    a3_low*cos(3*w_low.*q) + b3_low*sin(3*w_low.*q) + a4_low*cos(4*w_low.*q) + b4_low*sin(4*w_low.*q) + ...
    a5_low*cos(5*w_low.*q) + b5_low*sin(5*w_low.*q);      %fourier5

figure(8)
xlabel('q [-]','Interpreter','latex','FontSize',16)
ylabel('$\eta_i$ [-]','Interpreter','latex','FontSize',16)
title('Fourier series $\eta_i ( q )$ curves (n=6)','Interpreter','latex','FontSize',16)
hold on

for i=1:length(x)
    y = (1-x(i))*f_high + x(i)*f_low;
    txt=['$\Omega = $',num2str(round(s_query(i),2))];
    plot(q,y,'-','LineWidth',1,'DisplayName',txt);
    set(legend,'Interpreter','latex','FontSize',10,'Location','south')
end

axis([0 2 0 1.05])
hold off
legend show


%--------------------------------------------------------------------------
% 3. TWO-TERM EXPONENTIAL FUNCTIONS
%    e1(q) for q<=1, e2(q) for q>=1
%--------------------------------------------------------------------------

q=linspace(0,1.6,161);

q1=q(find(q<=1));   q2=q(find(q>1));

%High head:
f_high_1 = exp1_a_high*exp(exp1_b_high*q1) + exp1_c_high*exp(exp1_d_high*q1);   %q<=1
f_high_2 = exp2_a_high*exp(exp2_b_high*q2) + exp2_c_high*exp(exp2_d_high*q2);   %q>1
f_high = [f_high_1,f_high_2];
%Low head:
f_low_1 = exp1_a_low*exp(exp1_b_low*q1) + exp1_c_low*exp(exp1_d_low*q1);        %q<=1
f_low_2 = exp2_a_low*exp(exp2_b_low*q2) + exp2_c_low*exp(exp2_d_low*q2);        %q>1
f_low = [f_low_1,f_low_2];

figure(9)
xlabel('q [-]','Interpreter','latex','FontSize',16)
ylabel('$\eta_i$ [-]','Interpreter','latex','FontSize',16)
title('$\eta_i ( q )$ Exponential curves','Interpreter','latex','FontSize',16)
hold on

for i=1:length(x)
    y = (1-x(i))*f_high + x(i)*f_low;
    txt=['$\Omega = $',num2str(round(s_query(i),2))];
    plot(q,y,'-','LineWidth',1,'DisplayName',txt);
    set(legend,'Interpreter','latex','FontSize',10,'Location','south')
end

axis([0 2 0 1.05])
hold off
legend show


%--------------------------------------------------------------------------
% 4. TWO-TERM POWER FUNCTIONS
%    pow1(q) for q<=1, pow2(q) for q>=1
%--------------------------------------------------------------------------

q1=q(find(q<=1));   q2=q(find(q>1));

%High head:
f_high_1 = pow1_a_high*q1.^pow1_b_high + pow1_c_high;        %q<=1
f_high_2 = pow2_a_high*q2.^pow2_b_high + pow2_c_high;        %q>1
f_high = [f_high_1,f_high_2];
%Low head:
f_low_1 = pow1_a_low*q1.^pow1_b_low + pow1_c_low;            %q<=1
f_low_2 = pow2_a_low*q2.^pow2_b_low + pow2_c_low;            %q>1
f_low = [f_low_1,f_low_2];

figure(10)
xlabel('q [-]','Interpreter','latex','FontSize',16)
ylabel('$\eta_i$ [-]','Interpreter','latex','FontSize',16)
title('$\eta_i ( q )$ Power curves','Interpreter','latex','FontSize',16)
hold on

for i=1:length(x)
    y = (1-x(i))*f_high + x(i)*f_low;
    txt=['$\Omega = $',num2str(round(s_query(i),2))];
    plot(q,y,'-','LineWidth',1,'DisplayName',txt);
    set(legend,'Interpreter','latex','FontSize',10,'Location','south')
end

axis([0 2 0 1.05])
hold off
legend show
