% Hill charts from non-linear turbine model with eta_i implementation specified in eta_i functions at the bottom of script

% clear all
close all
clc


%--------------------------------------------------------------------------
% Medium head turbine
%--------------------------------------------------------------------------

% Design parameters from excel sheet - choose turbine by specifying column, run its 'eta_i_xxx' script before this script 
 design=table2array(readtable('Hillchart_r3_medBEP.xlsx','Sheet','Turbin_design','Range','T9:T80'));

% necessary model input:
 alfa_1R=design(49,1); sigma=design(53,1); psi=design(54,1); xi=design(56,1);

%--------------------------------------------------------------------------
y_query=linspace(0.3,1.4,12);                   %y=1.0 included
n_query=linspace(0,1.76,177);                   %n=1.0 included
q_query=linspace(0.1,1.76,167);                 %q=1.0 included
h=1;

n_query2=linspace(0.86,1.71,100);
q_query2=linspace(0.08,1.48,100);
%--------------------------------------------------------------------------

figure(1)
axis([0 1.8 0 1.8])
xlabel('$\tilde{\omega}$ [-]','Interpreter','latex','FontSize',16)
ylabel('$q$ [-]','Interpreter','latex','FontSize',16)
title('Model with $\eta_i(q)$: Hill diagram at h=1','Interpreter','latex','FontSize',16)
set(legend,'Interpreter','latex','FontSize',10,'Location','west')
hold on

%torque
t=zeros(length(q_query),length(n_query));       %each row const flow, each column const speed
for j=1:length(n_query)
    qdivy=sqrt(h-sigma*(n_query(j)^2-1));
    y=q_query./qdivy;
    alfa_1=asin(y.*sin(alfa_1R*pi/180));        %radians
    m_S=xi*qdivy*(cos(alfa_1)+tan(alfa_1R*pi/180)*sin(alfa_1));
    
    t(:,j)=eta_i(q_query).*q_query.*(m_S - psi.*n_query(j));
end

%efficiency
eta=zeros(length(q_query),length(n_query));     %each row const flow, each column const speed
for i=1:length(q_query)
    eta(i,:)=(t(i,:).*n_query)./(q_query(i)*h);
end

[N,Q]=meshgrid(n_query,q_query);                %each column in N has const speed
                                                %each row in Q has const flow
ETA=real(eta);     

elev=[0.01 linspace(0.05,0.8,16) linspace(0.825,1.00,8)];

contour(N,Q,ETA,elev,'-','LineWidth',1)
colorbar
caxis([0 1])

%flow
q=zeros(length(y_query),length(n_query));       %each row const opening, each column const speed
for i=1:length(y_query)
    q(i,:)=y_query(i)*sqrt(h-sigma*(n_query.^2-1));
    
    %plot one curve per opening degree
    plot(n_query,q(i,:),'-','LineWidth',1)
end

plot(n_query2,ones(length(n_query2))*min(q_query2),'k--',n_query2,ones(length(n_query2))*max(q_query2),'k--',...
    ones(length(q_query2))*min(n_query2),q_query2,'k--',ones(length(q_query2))*max(n_query2),q_query2,'k--',...
    'LineWidth',1)

legend('$\tilde{\eta}$','y = 0.3','y = 0.4','y = 0.5','y = 0.6','y = 0.7','y = 0.8','y = 0.9',...
       'y = 1','y = 1.1','y = 1.2','y = 1.3','y = 1.4')

%--------------------------------------------------------------------------

% uncomment the relevant eta_i(q) function
% eta_i multiplied into torque equation, should affect t-, p- and eta-plots
% q = single flow value/ vector at constant speed/ opening degree

%--------------------------------------------------------------------------

% % 1. POLYNOMIAL FUNCTION
% function y=eta_i(q)
%     global poly_p1 poly_p2 poly_p3 poly_p4 poly_p5 poly_p6 poly_p7 poly_p8 poly_p9 poly_p10
%     y = poly_p1*q.^9 + poly_p2*q.^8 + poly_p3*q.^7 + poly_p4*q.^6 + poly_p5*q.^5 + poly_p6*q.^4 + ...
%         poly_p7*q.^3 + poly_p8*q.^2 + poly_p9*q + poly_p10;
% end

% 2. FOURIER SERIES FUNCTION
function y=eta_i(q)
    global fou_a0 fou_a1 fou_b1 fou_a2 fou_b2 fou_a3 fou_b3 fou_a4 fou_b4 fou_a5 fou_b5 fou_w
    y = fou_a0 + fou_a1*cos(1*fou_w.*q) + fou_b1*sin(1*fou_w.*q) + fou_a2*cos(2*fou_w.*q) + fou_b2*sin(2*fou_w.*q)...
    + fou_a3*cos(3*fou_w.*q) + fou_b3*sin(3*fou_w.*q) + fou_a4*cos(4*fou_w.*q) + fou_b4*sin(4*fou_w.*q)...
    + fou_a5*cos(5*fou_w.*q) + fou_b5*sin(5*fou_w.*q);
end

% % 3. TWO-TERM EXPONENTIAL FUNCTIONS
% function y=eta_i(q)
%     global expo1_a expo1_b expo1_c expo1_d expo2_a expo2_b expo2_c expo2_d
%     y=zeros(size(q));  
%     
%     for k=1:length(q)
%         if q(k)<=1
%             y(k) = expo1_a*exp(expo1_b*q(k)) + expo1_c*exp(expo1_d*q(k));
%         elseif q(k)>1
%             y(k) = expo2_a*exp(expo2_b*q(k)) + expo2_c*exp(expo2_d*q(k));
%         end
%     end
% end

% % 4. TWO-TERM POWER FUNCTIONS
% function y=eta_i(q)
%     global pow1_a pow1_b pow1_c pow2_a pow2_b pow2_c
%     y=zeros(size(q));
%     
%     for k=1:length(q)
%         if q(k)<=1
%             y(k) = pow1_a*q(k)^pow1_b + pow1_c;
%         elseif q(k)>1
%             y(k) = pow2_a*q(k)^pow2_b + pow2_c;
%         end
%     end
% end

% % 5. PARABOLA PROPOSED BY NIELSEN
% function y=eta_i(q)
%     y=q.*(2-q);
% end